# pycocotools stubs

[![PyPI](https://img.shields.io/pypi/v/pycocotools-stubs?color=green&style=flat)](https://pypi.org/project/pycocotools-stubs)
[![PyPI - Implementation](https://img.shields.io/pypi/implementation/pycocotools-stubs?style=flat)](https://pypi.org/project/pycocotools-stubs)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pycocotools-stubs?style=flat)](https://pypi.org/project/pycocotools-stubs)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/pycocotools-stubs?style=flat-square)](https://pypistats.org/packages/pycocotools-stubs)
[![License](https://img.shields.io/pypi/l/pycocotools-stubs?style=flat)](https://opensource.org/licenses/MIT)
![Linting](https://github.com/hoel-bagard/pycocotools-stubs/actions/workflows/pre-commit.yaml/badge.svg)


Unofficial python stubs for the [pycocotools package](https://pypi.org/project/pycocotools/).

An equivalents stubs is available on [typeshed](https://github.com/python/typeshed/tree/main/stubs/pycocotools).
This stubs are different on two points:
- They include the docstrings as they are otherwise not available in the IDE (as far as I know).
- They include numpy typing (not possible to do in typeshed).

## Installation

The package is available on pypi [here](https://pypi.org/project/pycocotools-stubs/), you can install it with:

```
pip install pycocotools-stubs
```
